import { KeyValueCache } from 'apollo-server-caching';
/**
 * SOAP Cache utility
 *
 * SOAP is sent as HTTP POST and its a non-idempotent. Thus it can not be cached
 * at HTTP level.
 *
 * This[1] is draft version of document for response caching for SOAP, but did
 * not found any implementation of it.
 *
 * Thus it make sense to client decide to cache it or not and for much duration.
 *
 * [1]: https://lists.w3.org/Archives/Public/www-ws/2001Aug/att-0000/ResponseCache.html
 */
export declare class SOAPCache {
    private keyValueCache;
    /**
     * A constructor
     *
     * @param {Object} keyValueCache a cache object from apollo server en
     */
    constructor(keyValueCache: KeyValueCache);
    /**
     * Get the cached value from cache by key
     *
     * @param {String} key a cache key
     * @return {Object} a value of the cached object
     *
     */
    get(key: string): Promise<any>;
    /**
     * Put value to be cached with the key
     *
     * @param {String} key a cache key
     * @param {Object} value the value to be cached
     * @param {Integer} ttl the ttl value in seconds
     *
     */
    put(key: string, value: any, ttl: number): Promise<void>;
}
