import { DataSource, DataSourceConfig } from 'apollo-datasource';
import { IOptions } from 'soap';
export interface CacheOptions {
    ttl: number;
}
export interface SoapClientOptions extends IOptions {
    soapHeader?: any;
}
/**
 * A Soap datasource class
 *
 */
export declare class SOAPDataSource<TContext = any> extends DataSource {
    private wsdl;
    private options;
    private cache;
    private context;
    private client;
    /**
     * constructor
     *
     * @param {String} wsdl a wsdl url of a soap service
     *
     */
    constructor(wsdl: string);
    /**
     * Intercept the request and append client options
     *
     * @param {IOptions} options an object options of [soap](https://www.npmjs.com/package/soap#options) npm module
     */
    protected willSendRequest(options: SoapClientOptions): Promise<void>;
    /**
     * A callback method to decide the soap response can be cached or not
     *
     * @param {Object} response
     * @return {Boolean} true if cachable or otherwise false.
     */
    protected shouldCache(response: any): boolean;
    /**
     * Implement the initialize method to get access to context
     * This will be called by apollo server
     *
     * @param {DataSourceConfig} config a datasource config object
     *
     */
    initialize(config: DataSourceConfig<TContext>): void;
    /**
     * Get a soap client for given wsdl url
     */
    private createClient;
    /**
     * Invoke the soap method
     *
     * @param {String} methodName the method name to Invoke
     * @param {Object} params the params for soap method
     * @param {CacheOptions} cacheOptions options for caching
     *
     */
    invoke(methodName: string, params?: any, cacheOptions?: CacheOptions): Promise<any>;
}
